@@ -2,7 +2,7 @@
 # -*- encoding: utf-8 -*-
 
 # copy to ~/.gimp-2.8/plug-ins/
-# dependencies: GIMP 2.8, python-imaging-tk
+# dependencies: GIMP 2.8, python-imaging-tk, python-pyaudio
 
 from gimpfu import register, main, pdb, PF_BOOL, PF_STRING, PF_RADIO, CLIP_TO_IMAGE
 from PIL import Image, ImageTk
@@ -152,9 +152,6 @@ def contrast(value):
     else:
         return 255 - value
 
-def set_ptt_pin(port, pin, state):
-    getattr(port, 'set' + pin)(state)
-
 def transmit_current_image(image, drawable, mode, vox, fskid, ptt_port, ptt_pin, ptt_state):
     sstv = MODULE_MAP[mode]
     if ptt_port is not None:
