@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 from __future__ import division
-from sstv import SSTV, byte_to_freq
+from six.moves import range
+from pysstv.sstv import SSTV, byte_to_freq
 
 
 class GrayscaleSSTV(SSTV):
@@ -9,7 +10,7 @@ class GrayscaleSSTV(SSTV):
         self.pixels = self.image.convert('LA').load()
 
     def gen_image_tuples(self):
-        for line in xrange(self.HEIGHT):
+        for line in range(self.HEIGHT):
             for item in self.horizontal_sync():
                 yield item
             for item in self.encode_line(line):
@@ -18,7 +19,7 @@ class GrayscaleSSTV(SSTV):
     def encode_line(self, line):
         msec_pixel = self.SCAN / self.WIDTH
         image = self.pixels
-        for col in xrange(self.WIDTH):
+        for col in range(self.WIDTH):
             pixel = image[col, line]
             freq_pixel = byte_to_freq(pixel[0])
             yield freq_pixel, msec_pixel
